

TODO_32_99_70_35: figure out how JSONPath can be used for more compact and flexible assertions (via lambdas querying JSON parts)

Extend EnvMock to assert returned JSON via JSONPath:
https://www.digitalocean.com/community/tutorials/python-jsonpath-examples

Specifically, currently, we only assert is something is equals to something (at most, when it does not exist),
but we want to assert that it is not of specific value (not found for specific values).
